#
# Makefile Template for Tessy
# Compiler: TASKING Tricore VX 3.0
# Debugger: TASKING VX
# Template Version: 2
#

# Defines to be generated by Tessy:
#
# BUFFER_SIZE           :=
# COMPILER_DEFINES      :=
# COMPILER_INCLUDES     :=
# COMPILER_INSTALL_PATH :=
# CPU                   :=
# ENDIANESS             :=
# EXEFILE_EXTENSION     :=
# LINKER_FILE           :=
# MODULE_PATH           :=
# MODULE_PATH_DOS       :=
# OBJFILE_EXTENSION     :=
# PROJECTROOT           :=
# STARTUP_FILE          :=
# TARGET_INSTALL_PATH   :=
# TESSY_BIN             :=
# TESSY_SYS             :=
# TESTOBJECT            :=
# USER_LINK_OPTIONS     :=

#####################################################################
#BEGIN_DEFINES
#####################################################################

#
# Special macros for includes and defines
#
TS_DEF_SEPARATOR :=-D
define TS_DEFINE
$(subst ;, $(TS_DEF_SEPARATOR),$(1))
endef

TS_INC_SEPARATOR :=-I
define TS_INCLUDE
$(subst ;, $(TS_INC_SEPARATOR),$(1))
endef

TESSY_SYS_DOS   := $(shell ts_pathname -s '$(TESSY_SYS)')
MODULE_PATH_DOS := $(shell ts_pathname -s '$(MODULE_PATH)')
TASKING_HOME    := $(shell ts_pathname -s '$(COMPILER_INSTALL_PATH)')
STARTUP_FILE    := $(shell ts_pathname -s '$(STARTUP_FILE)')

TS_NAME         := TS_TASKING_VX
IDE_NAME        := taskingvx
COMPANY_NAME    := tasking
PROCESSOR_NAME  := tricore
TS_BYTEORDER    := TS_HOST_BYTEORDER

ifeq ("little","$(ENDIANESS)")
  TS_BYTEORDER := TS_HOST_BYTEORDER
endif
ifeq ("big","$(ENDIANESS)")
  TS_BYTEORDER := TS_NET_BYTEORDER
endif
ifndef TS_BYTEORDER
  $(error Attribute 'Endianess' has invalid value '$(ENDIANESS)', only 'little' and 'big' are allowed.)
endif

all	 : check_success master slave

# Cygwin work around.
S_BUILDIN_TESSY_FLAG := $(wildcard $(MODULE_PATH)/tslows_builtin.tessy)

check_success :
ifneq ($(S_BUILDIN_TESSY_FLAG),)
	@echo *
	@echo * Obviously the last build failed. Cleaning up built-in files...
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@echo * Please, try again to generate a built-in target binary.
	@echo *
	@exit 1
endif

#
# MASTER & COMM Makefiles
# (you should not need to modify these settings)
#
M_COMM_MAKE    := $(TESSY_SYS)/make/master_$(IDE_NAME)_gnu_i386.mk
S_COMM_MAKE    := $(TESSY_SYS)/src/comm/comm_$(IDE_NAME)_$(COMPANY_NAME)_$(PROCESSOR_NAME).mk


#
#
# SLAVE
#

S_CC           := $(shell ts_pathname -s '$(TASKING_HOME)')\bin\cctc.exe
S_ASM          := $(shell ts_pathname -s '$(TASKING_HOME)')\bin\cctc.exe
S_LINK         := $(shell ts_pathname -s '$(TASKING_HOME)')\bin\cctc.exe
S_INCLUDES     := -I"$(TESSY_SYS_DOS)\include\tessy\comm" -I"$(MODULE_PATH_DOS)" -I"$(TASKING_HOME)\include"
S_STUB_OBJECT  := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs$(OBJFILE_EXTENSION)
S_UC_OBJECT    := $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr$(OBJFILE_EXTENSION)

ifeq ($(COMPILER_DIALECT),)
	COMPILER_DIALECT := --iso=99
endif

# Options to be copied from the Tasking EDE generated makefile
#
# CPU = "TC39x"
TASKING_EDE_OPT_CC  := -C$(CPU) --lsl-core=vtc -t -Wa-H"sfr/regtc39x.def" -Wa-gAHLs --emit-locals=-equs,-symbols \
					   -Wa-Ogs -Wa--error-limit=42 -H"sfr/regtc39x.sfr" $(COMPILER_DIALECT) --language=-gcc,-volatile,+strings,-kanji \
					   --fp-model=3 --switch=auto --align=0 --default-near-size=8 --default-a0-size=0 --default-a1-size=0 -O0 --tradeoff=2 --compact-max-size=200 -g --error-limit=42 --source
					   
TASKING_EDE_OPT_ASM := -C$(CPU) --lsl-core=vtc -t -Wa-H"sfr/regtc39x.def" -Wa-gAHLs --emit-locals=-equs,-symbols -Wa-Ogs -Wa--error-limit=42

TASKING_EDE_OPT_LC  := -C$(CPU) --lsl-core=vtc -t "$(LINKER_FILE)" -Wl-OtxycL --no-map-file \
                       -Wl--map-file="$(MODULE_PATH_DOS)\ts_$(TESTOBJECT).mapxml":XML \
                       -Wl-mcrfiklSmNOduQ -Wl--error-limit=42 -g --fp-model=3

#
#
S_COMP_OPTIONS := $(TASKING_EDE_OPT_CC) -e -w -DTESSY -DTS_SLAVE -D$(TS_NAME) -DTS_TRICORE -DTS_HAVE_FLOAT \
						-DTS_HAVE_FLOAT64	-DTS_HAVE_INT64

S_LINK_OPTIONS	:= $(TASKING_EDE_OPT_LC) $(LIBRARIES) -L"$(TASKING_HOME)\lib\tc162"

#####################################################################
#END_DEFINES
#####################################################################

#####################################################################
#BEGIN_SOURCE
#####################################################################

#
# Template rules
#
$(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER)$(OBJFILE_EXTENSION): $(MODULE_PATH_DOS)\ts_src$$(SOURCENUMBER).c
	$(S_CC) $(S_INCLUDES) $(call TS_INCLUDE,$(USER_INCLUDES$$(SOURCENUMBER))) $(S_COMP_OPTIONS) \
		$(call TS_DEFINE,$(USER_DEFINES$$(SOURCENUMBER))$(S_COM_OPTIONS)) \
		$(USER_COMP_OPTIONS$$(SOURCENUMBER)) -c "$<" -o $@


#####################################################################
#END_SOURCE
#####################################################################

#####################################################################
#BEGIN_TARGETS
#####################################################################

ifneq ($(S_GenerateBuiltinData),)
TARGET_FLAG := d
BUILTIN_OBJ := $(MODULE_PATH_DOS)\tslows_builtin$(OBJFILE_EXTENSION)
master :
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin$(OBJFILE_EXTENSION)
else
TARGET_FLAG := s
BUILTIN_OBJ :=
master : $(MODULE_PATH)\ts_$(TESTOBJECT)_m.exe
endif
slave  : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION)

# COMPILE USERCODE / STUBS
#
$(S_UC_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_usr.c
	@echo ***** Compiling Usercode *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -I$(MODULE_PATH_DOS) -c $< -o $@

$(S_STUB_OBJECT) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_stubs.c
	@echo ***** Compiling Stubs *****
	$(S_CC) $(S_INCLUDES) $(S_COMP_OPTIONS) -I$(MODULE_PATH_DOS) -c $< -o $@


#
# COMPILE/LINK MASTER
#

include $(M_COMM_MAKE)


#
# COMPILE SLAVE COMMUNICATION MODULES

include $(S_COMM_MAKE)



#
#
# COMPILE/LINK SLAVE
#
$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) : $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s.c
	@echo *
	@echo ***** Compiling Slave *****
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -I$(MODULE_PATH_DOS) -c $< -o $@

#
# Handle Board Files
#
ifeq ("true","$(USE_BOARD_FILES)")
ifeq ("","$(INITOBJDIR)")
$(error Attribute 'Use Board Files' is set to true but 'InitObjDir' is empty.)
endif
INITOBJDIR := $(shell ts_pathname -s '$(INITOBJDIR)')
ifeq ("","$(INITSRCDIR)")
$(info Attribute 'InitSrcDir' is empty. Using objects for linking only.)
START_OBJS := $(wildcard $(INITOBJDIR)/*$(OBJFILE_EXTENSION))
else
INITSRCDIR := $(shell ts_pathname -s '$(INITSRCDIR)')
START_OBJS := $(patsubst $(INITSRCDIR)/%.c,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.c)) \
              $(patsubst $(INITSRCDIR)/%.s,$(INITOBJDIR)/%$(OBJFILE_EXTENSION),$(wildcard $(INITSRCDIR)/*.s))

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.c
	$(S_CC) $(S_COMP_OPTIONS) $(S_INCLUDES) -I$(INITSRCDIR) -c "$<" -o "$@"

$(INITOBJDIR)/%$(OBJFILE_EXTENSION) : $(INITSRCDIR)/%.s
	$(S_CC) $(TASKING_EDE_OPT_ASM ) $(S_INCLUDES) -c "$<" -o "$@"
endif
ifeq ("","$(START_OBJS)")
$(warning Attribute 'Use Board Files' is set to true but no objects were found.)
endif
endif


$(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION) : $(STARTUP_FILE) $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
															$(START_OBJS) \
															$(S_SRC_OBJECTS) \
															$(S_UC_OBJECT) \
															$(S_STUB_OBJECT) \
															$(S_OBJECTS)
	@echo *
	@echo ***** Linking Slave *****
	$(S_LINK) $(S_LINK_OPTIONS) -o $@ $(USER_LINK_OPTIONS) $(STARTUP_FILE) \
					$(S_OBJECTS) $(BUILTIN_OBJ) $(MODULE_PATH_DOS)\ts_$(TESTOBJECT)_s$(OBJFILE_EXTENSION) \
					$(S_SRC_OBJECTS) $(S_UC_OBJECT) $(S_STUB_OBJECT) $(START_OBJS)
ifneq ($(S_GenerateBuiltinData),)
	@-ts_rm -f "$(MODULE_PATH)"/tslows_builtin.*
	@echo *
	@echo * Generated target binary '$(shell ts_pathname -w $(MODULE_PATH)/ts_$(TESTOBJECT)_$(TARGET_FLAG)$(EXEFILE_EXTENSION))' containing builtin data.
	@echo *
endif
						

#####################################################################
#END_TARGETS
#####################################################################

